<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Forklare</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Oversæt</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Spørg AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Resumé</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik på bakkeikonet
eller tryk på genvejen igen, for at stoppe optagelse</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Und tag din skærm under optagelse</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Optagelse</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Luk (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopier til udklipsholder (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Skærmoptagelse</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Gem mislykkedes. Gem den venligst i din hjemmemappe.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Skærmbilledet er færdigt</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>markeringsområde</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Udklipsholder</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Gemmer skærmbilledoptagelsen, venligst vent...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Da vindueeffekten er deaktivert under processen, skal optagelsen stoppes</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fæst skærmbilleder</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Skærmbilledet er færdigt og kopieret til udklipsholder</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Hver spørgsmål</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Angivet sted</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation type="unfinished">Angiv en mappe ved opbevaring</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation type="unfinished">Ændr stien ved opbevaring</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fæst skærmbilleder</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbilled</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbilled</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Optagelse</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Optagelse færdig</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Åbn mappe</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation type="unfinished">Hver spørgsmål</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Angivet sted</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Vælg et sted ved opbevaring</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Opdateret sted ved opbevaring</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Skærmoptagelse starter om %1 sekunder</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Få hjælp.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Mislykket med at tage et kontinuerligt skærmbilled.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Kom til bunden af scrollområdet</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Kom til maksimærlængde</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>juster opfangerområdet</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scroll din musescroll eller klik for at tage et scrollskærmbilled</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Forsink scrollhastigheden</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Ugyldigt område, klik for </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Skriv teksten her</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/skærmbillede</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Afslut/gem</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Justering af størrelse</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hurtig start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Vinduesskærmbillede</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Forsink skærmbillede</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Fuldt skærmbillede</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Blyant</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Højere øverst</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Højere nederst</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Bredere til venstre</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Bredere til højre</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Lavere øverst</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Lavere nederst</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Lavere til venstre</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Lavere til højre</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tastetryk</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start optagelse</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Optag</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mus</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Værktøjer</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Hent tekst</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fæst skærmbilleder</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Start OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Start scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Opfølg</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rektangel
Hold Shift nede for at tegne et kvadrat</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellipse
Hold Shift nede for at tegne en cirkel</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Børste
Hold Shift nede for at tegne en ret linje</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Justér stærken på uskarp (Scroll for at justere det)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Justér børstestørrelse (Scroll for at justere det)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Justér tekstdimension (Scroll for at justere det)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Vis tasttryk (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Skjul tasttryk (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Vis tasttryk (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Tænd kamera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Sluk kamera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skærmbillede</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Indstillinger (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Systemlyd</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Vis pointer</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Vis klik</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gem til</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linje (L)
Hold Shift nede for at tegne en lodret eller vandret linje</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Pil (X)
Tryk og hold Shift for at tegne en vertikal eller horisontal pil</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Blyant (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Måske (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Udtræk tekst (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fæst skærmbilleder (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Fortryd (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Ændr stien ved opbevaring</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Randeffekter</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Skygge</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Enhed</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Udtræk tekst</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometriske værktøjer (R)
Hold Shift nede for at tegne kvadrater eller cirkler.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Gem til lokal</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Gem til %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Angivet sted</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Opdateret sted ved opbevaring</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Vælg et sted ved opbevaring</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>AI Skærmbillede (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Gem til Skrivebord</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Gem til billeder</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Luk (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopier til udklipsholder (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Justér opfølgningsområdet indenfor %1*%2 for at få bedre videoeffekt</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Skærmbilledoptagelse understøttes ikke i øjeblikket</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
</TS>
